@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 module Bitstest(tests) where
 import Test.HUnit
-import MissingH.Bits
+import Data.Bits.Utils
 import Data.Word
 
 test_fromBytes =
