@@ -18,8 +18,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 module IOtest() where
 import Test.HUnit
-import MissingH.IO
-import Testutil
+import System.IO
+import Test.HUnit.Utils
 
 
 
