@@ -21,15 +21,11 @@ import Test.HUnit
 import qualified MIMETypestest
 import qualified Listtest
 import qualified Maptest
-import qualified AnyDBMtest
 import qualified Pathtest
 import qualified Strtest
 import qualified IOtest
 import qualified Bitstest
-import qualified Network.FTP.Parsertest
 import qualified Eithertest
-import qualified ConfigParser.Parsertest
-import qualified ConfigParser.Maintest
 import qualified CRC32POSIXtest
 import qualified CRC32GZIPtest
 import qualified GZiptest
@@ -50,7 +46,6 @@ tests = TestList [TestLabel "test1" test1,
                  TestLabel "Time" Timetest.tests,
                  TestLabel "Map" Maptest.tests,
                  TestLabel "ProgressTracker" ProgressTrackertest.tests,
-                 TestLabel "AnyDBM" AnyDBMtest.tests,
                  TestLabel "Path" Pathtest.tests,
                  TestLabel "WildMatch" WildMatchtest.tests,
                  TestLabel "HVIO" HVIOtest.tests,
@@ -58,10 +53,7 @@ tests = TestList [TestLabel "test1" test1,
                  TestLabel "Glob" Globtest.tests,
                  TestLabel "MIMETypes" MIMETypestest.tests,
                  TestLabel "Bitstest" Bitstest.tests,
-                 TestLabel "Network.FTP.Parser" Network.FTP.Parsertest.tests,
                  TestLabel "Eithertest" Eithertest.tests,
-                 TestLabel "ConfigParser.RunParser" ConfigParser.Parsertest.tests,
-                 TestLabel "ConfigParser.Main" ConfigParser.Maintest.tests,
                  TestLabel "CRC32POSIXtest" CRC32POSIXtest.tests,
                  TestLabel "CRC32GZIPtest" CRC32GZIPtest.tests,
                  TestLabel "GZiptest" GZiptest.tests]
